@@ -2,7 +2,8 @@
 test_that("general test case empty_dag()", {
 
   expected <- list(root_nodes=list(), child_nodes=list(),
-                   tx_nodes=list())
+                   tx_nodes=list(), networks=list(),
+                   td_networks=list())
   class(expected) <- "DAG"
 
   out <- empty_dag()
